IF OBJECT_ID('Variables_CascadedValuesByApplication') IS NOT NULL DROP VIEW Variables_CascadedValuesByApplication
GO
IF OBJECT_ID('Variables_CascadedValuesByExecution') IS NOT NULL DROP VIEW Variables_CascadedValuesByExecution
GO
IF OBJECT_ID('Variables_GetValuesForExecution') IS NOT NULL DROP FUNCTION Variables_GetValuesForExecution
GO


CREATE FUNCTION [Variables_GetValuesForExecution]
(
	@ExecutionId INT,
	@Server_Id INT,
    @ServerRole_Id INT,
	@Deployable_Id INT
) RETURNS @vvals TABLE ([Variable_Name] VARCHAR(50), [Value_Text] VARCHAR(MAX), [Scope_Code] CHAR(1), [Sensitive_Indicator] CHAR(1))
BEGIN

	DECLARE @Application_Id INT
	DECLARE @ApplicationGroup_Id INT
	DECLARE @Environment_Id INT
	DECLARE @Release_Number RELEASENUMBER
	DECLARE @Build_Number BUILDNUMBER
	DECLARE @Release_Id INT
	DECLARE @Build_Id INT
	DECLARE @Promotion_Id INT
	DECLARE @PipelineStage_Name VARCHAR(50)

	SELECT @Application_Id = A.[Application_Id],
	       @Environment_Id = E.[Environment_Id],
		   @Release_Number = R.[Release_Number],
		   @Build_Number = B.[Build_Number],
		   @ApplicationGroup_Id = A.[ApplicationGroup_Id],
		   @Release_Id = R.[Release_Id],
		   @Build_Id = B.[Build_Id],
		   @Promotion_Id = BP.[Promotion_Id],
		   @PipelineStage_Name = BP.[PipelineStage_Name]
	  FROM [BuildExecutions] BE
	       INNER JOIN [BuildPromotions] BP
		           ON BP.[Promotion_Id] = BE.[Promotion_Id]
		   INNER JOIN [Builds] B
		           ON B.[Build_Id] = BP.[Build_Id]
		   INNER JOIN [Releases] R
		           ON R.[Release_Id] = B.[Release_Id]
	       INNER JOIN [Applications] A
		           ON A.[Application_Id] = R.[Application_Id]
		    LEFT JOIN [Environments] E
			       ON E.[Environment_Id] = BE.[Environment_Id]
     WHERE BE.[Execution_Id] = @ExecutionId

	DECLARE @VDEC_Ids TABLE ([VariableDeclaration_Id] INT)
	DECLARE @VDEF_Ids TABLE ([VariableDefinition_Id] INT, [AppGroupDepth] INT)

	INSERT @VDEF_Ids
	SELECT VDEF.[VariableDefinition_Id], 0
	  FROM [VariableDefinitions] VDEF
	 WHERE (VDEF.[Application_Id] IS NULL OR VDEF.[Application_Id] = @Application_Id)
	   AND (VDEF.[ApplicationGroup_Id] IS NULL OR VDEF.[ApplicationGroup_Id] = @ApplicationGroup_Id)
	   AND (VDEF.[Release_Id] IS NULL OR VDEF.[Release_Id] = @Release_Id)
	   AND (VDEF.[Build_Id] IS NULL OR VDEF.[Build_Id] = @Build_Id)
	   AND (VDEF.[Environment_Id] IS NULL OR VDEF.[Environment_Id] = @Environment_Id)
	   AND (VDEF.[Execution_Id] IS NULL OR VDEF.[Execution_Id] = @ExecutionId)
	   AND (VDEF.[Server_Id] IS NULL OR VDEF.[Server_Id] = @Server_Id)
       AND (VDEF.[ServerRole_Id] IS NULL OR VDEF.[ServerRole_Id] = @ServerRole_Id)
	   AND (VDEF.[Deployable_Id] IS NULL OR VDEF.[Deployable_Id] = @Deployable_Id)
	   AND (VDEF.[Promotion_Id] IS NULL OR VDEF.[Promotion_Id] = @Promotion_Id)

    -- hack for application group groups
    INSERT @VDEF_Ids
    SELECT VDEF.[VariableDefinition_Id], AGA.[Level]
      FROM [VariableDefinitions] VDEF
     INNER JOIN dbo.ApplicationGroups_GetAncestorGroups(@ApplicationGroup_Id) AGA
             ON @ApplicationGroup_Id IS NOT NULL
            AND AGA.[Level] > 0
            AND AGA.[ApplicationGroup_Id] = VDEF.[ApplicationGroup_Id]
       

	INSERT @VDEC_Ids
	SELECT VDEC.[VariableDeclaration_Id]
	  FROM [VariableDeclarations] VDEC
	 WHERE (VDEC.[Scoped_Application_Id] IS NULL OR VDEC.[Scoped_Application_Id] = @Application_Id)
	   AND (VDEC.[Scoped_Environment_Id] IS NULL OR VDEC.[Scoped_Environment_Id] = @Environment_Id)
	   AND (VDEC.[Scoped_PipelineStage_Name] IS NULL OR VDEC.[Scoped_PipelineStage_Name] = @PipelineStage_Name)
	   AND ((@Server_Id IS NULL AND VDEC.[Scope_Code] <> 'V') OR @Server_Id IS NOT NULL)
	   AND ((@Deployable_Id IS NULL AND VDEC.[Scope_Code] <> 'D') OR @Deployable_Id IS NOT NULL)
	   AND NOT EXISTS(SELECT * FROM [VariableDefinitions] _VDEF
					   WHERE _VDEF.[VariableDefinition_Id] IN (SELECT [VariableDefinition_Id] FROM @VDEF_Ids)
						 AND _VDEF.[Variable_Name] = VDEC.[Variable_Name]
						 AND _VDEF.[Scope_Code] = VDEC.[Scope_Code])

	INSERT INTO @vvals ([Variable_Name], [Value_Text], [Scope_Code], [Sensitive_Indicator])
	SELECT [Variable_Name], [Value_Text], [Scope_Code], [Sensitive_Indicator]
	  FROM (SELECT *, [Rank] = RANK() OVER (PARTITION BY [Variable_Name] ORDER BY CHARINDEX([Scope_Code], 'SELVGADRBPX') DESC, [AppGroupDepth] ASC)
			  FROM (SELECT [Variable_Name], [Value_Text], [Scope_Code], [Sensitive_Indicator], NULL AS [Scoped_Environment_Id], VD1.[AppGroupDepth]
                        FROM @VDEF_Ids VD1
                        INNER JOIN [VariableDefinitions] VD2
                                ON VD1.[VariableDefinition_Id] = VD2.[VariableDefinition_Id]
						   UNION ALL
					SELECT [Variable_Name], [DefaultValue_Text], [Scope_Code], [Sensitive_Indicator], [Scoped_Environment_Id], 0 AS [AppGroupDepth]
					  FROM [VariableDeclarations]
					 WHERE [VariableDeclaration_Id] IN (SELECT [VariableDeclaration_Id] FROM @VDEC_Ids))_)_
	 WHERE [Rank] = 1
  
  RETURN
END
GO