EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'BuildSchedules_SetVariableDefinition',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates a variable definition to use with a scheduled build',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[BuildSchedules_SetVariableDefinition]') IS NOT NULL DROP PROCEDURE [BuildSchedules_SetVariableDefinition]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [BuildSchedules_SetVariableDefinition]
(
	@Schedule_Id INT,
	@VariableDeclaration_Id INT,
	@Value_Text VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
	
	IF @Value_Text IS NULL OR @Value_Text = ''
	BEGIN

		DELETE [BuildScheduleVariableDefinitions]
		 WHERE [Schedule_Id] = @Schedule_Id
		   AND [VariableDeclaration_Id] = @VariableDeclaration_Id

	END
	ELSE IF EXISTS(SELECT *
		            FROM [BuildScheduleVariableDefinitions]
				   WHERE [Schedule_Id] = @Schedule_Id
				     AND [VariableDeclaration_Id] = @VariableDeclaration_Id)
	BEGIN
		
		UPDATE [BuildScheduleVariableDefinitions]
		   SET [Value_Text] = @Value_Text
		 WHERE [Schedule_Id] = @Schedule_Id
		   AND [VariableDeclaration_Id] = @VariableDeclaration_Id
          
	END
	ELSE
	BEGIN

		INSERT INTO [BuildScheduleVariableDefinitions]
		([Schedule_Id], [VariableDeclaration_Id], [Value_Text])
		VALUES
		(@Schedule_Id, @VariableDeclaration_Id, @Value_Text)

	END
	
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [BuildSchedules_SetVariableDefinition] TO [BuildMasterUser_Role]
