EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_CreateBuild',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new build of an application.'
GO

IF OBJECT_ID('[Builds_CreateBuild]') IS NOT NULL DROP PROCEDURE [Builds_CreateBuild]
GO


SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_CreateBuild]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@BuildImporter_Configuration XML = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Release_Id INT
	SELECT @Release_Id = [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number

	DECLARE @Build_Sequence INT
	SET @Build_Sequence = COALESCE((SELECT MAX([Build_Sequence])
	                                  FROM [Builds]
							         WHERE [Release_Id] = @Release_Id), 0) + 1

	INSERT INTO [Builds]
	(
		[Release_Id],
		[Build_Number],
		[BuildStatus_Name],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[BuildImporter_Configuration],
		[Build_Sequence]
	)
	VALUES
	(
		@Release_Id,
		@Build_Number,
		'Active',
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		@BuildImporter_Configuration,
		@Build_Sequence
	)

	DECLARE @Build_Id INT
	SET @Build_Id = SCOPE_IDENTITY()

    UPDATE [Issues]
       SET [OpenedOn_Original_Build_Number] = @Build_Number
     WHERE [Release_Id] = @Release_Id
       AND [Closed_Indicator] = 'N'
       AND [OpenedOn_Original_Build_Number] IS NULL

    UPDATE [Issues]
       SET [ClosedOn_Original_Build_Number] = @Build_Number
     WHERE [Release_Id] = @Release_Id
       AND [Closed_Indicator] = 'Y'
       AND [ClosedOn_Original_Build_Number] IS NULL

	EXEC [Events_RaiseEvent] 'BLDNEW', @Application_Id, @Release_Number, @Build_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_CreateBuild] TO [BuildMasterUser_Role]
