EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_GetConfigurationFiles',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'ConfigurationFiles_Extended,ConfigurationFileInstances_Extended,ConfigurationFileVersions_Combined,ConfigurationFileVersions_ModifiedInstances',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets all configuration files that match the specified criteria.'
GO

IF OBJECT_ID('[ConfigurationFiles_GetConfigurationFiles]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_GetConfigurationFiles]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_GetConfigurationFiles]
(
	@Application_Id INT = NULL,
	@Deployable_Id INT = NULL,
	@IncludeInactive_Indicator YNINDICATOR = NULL,
	@IncludeInstances_Indicator YNINDICATOR = NULL,
	@IncludeVersions_Indicator YNINDICATOR = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	SET @IncludeInactive_Indicator = ISNULL(@IncludeInactive_Indicator, 'N')

	SELECT *
	  FROM [ConfigurationFiles_Extended]
	 WHERE [Application_Id] = ISNULL(@Application_Id, [Application_Id])
	   AND (@Deployable_Id IS NULL OR [Deployable_Id] = @Deployable_Id)
	   AND ([Active_Indicator] = 'Y' OR @IncludeInactive_Indicator = 'Y')
	 ORDER BY [Deployable_Name], [Active_Indicator] DESC, [FilePath_Text]

	SELECT *
	  FROM [ConfigurationFileInstances_Extended]
	 WHERE @IncludeInstances_Indicator = 'Y'
	   AND ([Active_Indicator] = 'Y' OR @IncludeInactive_Indicator = 'Y')
	   AND [Application_Id] = ISNULL(@Application_Id, [Application_Id])
	   AND (@Deployable_Id IS NULL OR [Deployable_Id] = @Deployable_Id)

	SELECT CFV.*
	  FROM [ConfigurationFileVersions_Combined] CFV
	       INNER JOIN [ConfigurationFiles] CF
		           ON CF.[ConfigurationFile_Id] = CFV.[ConfigurationFile_Id]
	 WHERE @IncludeVersions_Indicator = 'Y'
	   AND (CF.[Active_Indicator] = 'Y' OR @IncludeInactive_Indicator = 'Y')
	   AND (@Deployable_Id IS NULL OR CF.[Deployable_Id] = @Deployable_Id)
	   AND CF.[Application_Id] = ISNULL(@Application_Id, CF.[Application_Id])

	SELECT CFVMI.*
	  FROM [ConfigurationFileVersions_ModifiedInstances] CFVMI
	       INNER JOIN [ConfigurationFiles] CF
		           ON CF.[ConfigurationFile_Id] = CFVMI.[ConfigurationFile_Id]
	 WHERE @IncludeVersions_Indicator = 'Y'
	   AND (CF.[Active_Indicator] = 'Y' OR @IncludeInactive_Indicator = 'Y')
	   AND (@Deployable_Id IS NULL OR CF.[Deployable_Id] = @Deployable_Id)
	   AND CF.[Application_Id] = ISNULL(@Application_Id, CF.[Application_Id])

END
GO

GRANT EXECUTE ON [ConfigurationFiles_GetConfigurationFiles] TO [BuildMasterUser_Role]
