EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_ResequenceAction',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Changes the sequence of an action within a plan.'
GO


IF OBJECT_ID('[Plans_ResequenceAction]') IS NOT NULL DROP PROCEDURE [Plans_ResequenceAction]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_ResequenceAction]
(
	@DeploymentPlanActionGroup_Id INT,
	@Action_Sequence INT,
	@New_Action_Sequence INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	DECLARE @ActionGroup_Id INT
	SELECT @ActionGroup_Id = [ActionGroup_Id]
	  FROM [DeploymentPlanActionGroups]
	 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

	BEGIN TRANSACTION

	UPDATE [ActionGroupActions]
	   SET [Action_Sequence] = CASE
	          WHEN [ActionGroupActions].[Action_Sequence] = CUR.[Action_Sequence] 
	               THEN NEW.[Action_Sequence]
	          WHEN [ActionGroupActions].[Action_Sequence] BETWEEN CUR.[Action_Sequence] AND NEW.[Action_Sequence]
	               THEN [ActionGroupActions].[Action_Sequence] - 1
	          WHEN [ActionGroupActions].[Action_Sequence] BETWEEN NEW.[Action_Sequence] AND CUR.[Action_Sequence]
	               THEN [ActionGroupActions].[Action_Sequence] + 1
	          ELSE [ActionGroupActions].[Action_Sequence]
	          END
	  FROM [ActionGroupActions],
	       [ActionGroupActions] CUR,
	       [ActionGroupActions] NEW
	 WHERE CUR.[Action_Sequence] = @Action_Sequence
	   AND NEW.[Action_Sequence] = @New_Action_Sequence
	   AND @Action_Sequence <> @New_Action_Sequence
	   AND [ActionGroupActions].[ActionGroup_Id] = @ActionGroup_Id
	   AND CUR.[ActionGroup_Id] = @ActionGroup_Id
	   AND NEW.[ActionGroup_Id] = @ActionGroup_Id


	DECLARE @Plans TABLE ([DeploymentPlan_Id] INT)
	INSERT INTO @Plans
	SELECT DISTINCT([DeploymentPlan_Id])
	  FROM [DeploymentPlanActionGroups]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id
 
	WHILE ((SELECT COUNT(*) FROM @Plans) > 0)
	BEGIN

		DECLARE @DeploymentPlan_Id INT
		SET @DeploymentPlan_Id = (SELECT TOP 1 [DeploymentPlan_Id] FROM @Plans)
		DELETE @Plans WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

		EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	END

	UPDATE [ActionGroups]
	   SET [ModifiedOn_Date] = GETUTCDATE(),
	       [ModifiedBy_User_Name] = dbo.Session_GetUserName()
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

 	-- disable reexecution for anything that used the plan containing the action group
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
		                        FROM [BuildExecution_DeploymentPlans] BEDP
		                             INNER JOIN [DeploymentPlanActionGroups] DPAG
		                                     ON DPAG.[DeploymentPlan_Id] = BEDP.[Original_DeploymentPlan_Id]
		                       WHERE DPAG.[ActionGroup_Id] = @ActionGroup_Id)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_ResequenceAction] TO [BuildMasterUser_Role]
