EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_GetDependentReleases',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Releases_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets all releases with referenced deployables from a specified release.'
GO

IF OBJECT_ID('[Releases_GetDependentReleases]') IS NOT NULL DROP PROCEDURE [Releases_GetDependentReleases]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_GetDependentReleases]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

 
	SELECT RE.*
	  FROM [Releases_Extended] RE
	 WHERE EXISTS 
           (
	         SELECT *
			   FROM [ReleaseDeployables] RD
			        INNER JOIN [Releases] R
					        ON R.[Release_Id] = RD.[Release_Id]
					LEFT JOIN [Releases] R_REF
					       ON R_REF.[Release_Id] = RD.[Referenced_Release_Id]
	          WHERE RE.[Application_Id] = R.[Application_Id]
	            AND RE.[Release_Number] = R.[Release_Number]
	            AND R_REF.[Application_Id] = @Application_Id
	            AND R_REF.[Release_Number] = @Release_Number
	            
	       )
	   AND NOT ([Application_Id] = @Application_Id AND 
	            [Release_Number] = @Release_Number)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Releases_GetDependentReleases] TO [BuildMasterUser_Role]